The main function is pogitBvs which provides Bayesian variable
selection for a Poisson-Logistic (Pogit) model to account for potential
under-reporting of count data. The Pogit model, introduced by Winkelmann
and Zimmermann (1993), is specified by combining a Poisson model for the data
generating process of counts and a logit model for the fallible reporting
process, where the outcomes of both processes may depend on a set of
potential covariates.
By augmenting the observed data with the unobserved counts, the model
can be factorized into a Poisson and a binomial logit model part. Hence,
the MCMC sampling algorithm for this two-part model is based on
data augmentation and sampling schemes for a Poisson and a binomial
logit model.
Though part of the main function, the functions poissonBvs
and logitBvs can be used separately to perform
Bayesian variable selection for Poisson or binomial logit regression models.
An alternative to poissonBvs is provided by the function
negbinBvs to deal with overdispersion of count data.
The sampling algorithms are based on auxiliary mixture sampling
techniques.
All functions return an object of class "pogit" with methods
print.pogit, summary.pogit and
plot.pogit to summarize and display the results.
Winkelmann, R. and Zimmermann, K. F. (1993). Poisson-Logistic regression. Department of Economics, University of Munich, Working Paper No. 93 - 18.
pogitBvs, logitBvs, poissonBvs,
negbinBvs
## see examples for pogitBvs, logitBvs, poissonBvs and negbinBvs
Run the code above in your browser using DataLab