pogitThe default print method for a pogit object.
# S3 method for pogit
print(x, ...)an object of class pogit
further arguments passed to or from other methods (not used)
Returns basic information about the model, the number of observations and
covariates used, the number of regression effects subject to selection,
MCMC options and the runtime used for the sampling algorithm. See
summary.pogit for more details.