simul_pois2: Simulated data set
Description
The same simulation setup is used as in simul_pois1 but considers
clustered observations. 10 regressors are generated, six of them continuous
N(0,1)-variables and four binary with $p(x_i)=0.5$.
The regression effects are set to beta = {2,1,0.6,0,0,1.2,0,0,0.4,-0.2,0.3}.
To simulate clustering, it is assumed that each of
C=10 clusters is formed of 30 subjects and 10 random intercepts are generated
from a normal distribution with zero mean and standard deviation
$\theta$ = 0.1.
Format
A data frame with 300 rows and the following 12 variables:
y- number of counts for each covariate pattern in each cluster
cID- cluster ID of each count
X.0- intercept
X.1, X.2, X.3, X.4, X.5, X.6, X.7, X.8, X.9, X.10- covariates